===========
easyadwords
===========


.. image:: https://img.shields.io/pypi/v/easyadwords.svg
        :target: https://pypi.python.org/pypi/easyadwords

.. image:: https://readthedocs.org/projects/easyadwords/badge/?version=latest
        :target: https://easyadwords.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


User friendly wrapper for Google AdWords


* Free software: Apache Software License 2.0
* Documentation: https://easyadwords.readthedocs.io.


Features
--------

* Access most reporting functions of the powerful AdWords API (relatively) painlessly

Installation
------------

.. code-block:: bash

    $ pip install easyadwords
